==> qtjambi-websockets-debuginfo-macos-6.5.3.jar: sources/QtJambiWebSockets/QMaskGenerator_shell.h <==
#ifndef QMASKGENERATOR_SHELL_H
#define QMASKGENERATOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtWebSockets/qmaskgenerator.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QMaskGenerator_shell : public QMaskGenerator, public QtJambiShellInterface
{
public:
    QMaskGenerator_shell(QObject* parent0 = nullptr);
    ~QMaskGenerator_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    quint32 nextMask() override;
    bool seed() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMaskGenerator_access : public QMaskGenerator
{
    jint __qt_nextMask(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_seed(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QMASKGENERATOR_SHELL_H

==> qtjambi-websockets-debuginfo-macos-6.5.7.jar: sources/QtJambiWebSockets/QMaskGenerator_shell.h <==
#ifndef QMASKGENERATOR_SHELL_H
#define QMASKGENERATOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebSockets/qmaskgenerator.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QMaskGenerator_shell : public QMaskGenerator, public QtJambiShellInterface
{
public:
    QMaskGenerator_shell(QObject* parent0 = nullptr);
    ~QMaskGenerator_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QMaskGenerator_mshell;
    friend class QMaskGenerator_oshell;
};


class QMaskGenerator_mshell : public QMaskGenerator_shell
{
public:
    using QMaskGenerator_shell::QMaskGenerator_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QMaskGenerator_oshell : public QMaskGenerator_mshell
{
public:
    using QMaskGenerator_mshell::QMaskGenerator_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    quint32 nextMask() override;
    bool seed() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMaskGenerator_access : public QMaskGenerator
{
    jint __qt_nextMask(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_seed(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QMASKGENERATOR_SHELL_H
